#
# spec file for package python-dill
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-dill
Version:        0.3.7
Release:        1.4
Summary:        Module to serialize all of Python
License:        BSD-3-Clause
Group:          Development/Languages/Python
URL:            https://github.com/uqfoundation/dill
Source:         https://github.com/uqfoundation/dill/archive/dill-%{version}.tar.gz#/dill-%{version}.tar.gz
BuildRequires:  %{python_module dbm}
BuildRequires:  %{python_module devel >= 3.7}
BuildRequires:  %{python_module objgraph >= 1.7.2}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildRequires:  unzip
Requires(post): update-alternatives
Requires(postun):update-alternatives
Recommends:     python-objgraph >= 1.7.2
BuildArch:      noarch
%python_subpackages

%description
Dill extends python's `pickle` module for serializing and de-serializing
python objects to the majority of the built-in python types. Serialization
is the process of converting an object to a byte stream, and the inverse
of which is converting a byte stream back to on python object hierarchy.

Dill provides the user the same interface as the `pickle` module, and
also includes some additional features. In addition to pickling python
objects, `dill` provides the ability to save the state of an interpreter
session in a single command.

%prep
%autosetup -p1 -n dill-dill-%{version}
find dill -name '*.py' -exec sed -i '1{\@^#!%{_bindir}/env python@d}' {} \;

%build
%python_build

%install
%python_install
%python_expand rm -r %{buildroot}%{$python_sitelib}/dill/tests
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%python_clone -a %{buildroot}%{_bindir}/undill
%python_clone -a %{buildroot}%{_bindir}/get_gprof
%python_clone -a %{buildroot}%{_bindir}/get_objgraph

%check
export PYTHONDONTWRITEBYTECODE=1
export PYTHONPATH=%{_builddir}/dill-dill-%{version}
# Creative; copied from tox.ini
%python_exec dill/tests/__main__.py

%post
%{python_install_alternative undill get_objgraph get_gprof}

%postun
%python_uninstall_alternative undill

%files %{python_files}
%doc README.md
%license LICENSE
%python_alternative %{_bindir}/undill
%python_alternative %{_bindir}/get_gprof
%python_alternative %{_bindir}/get_objgraph
%{python_sitelib}/dill
%{python_sitelib}/dill-%{version}*-info

%changelog
* Sat Nov 25 2023 Dirk Müller <dmueller@suse.com>
- update to 0.3.7:
  * Fix _is_builtin_module
  * minor changes from PR #554
  * align LICENSE wording with BSD-3-Clause
  * Python 3 Metaclasses [Support ABC and Enums - Part 1]
  * Abstract Base Classes [Support ABC and Enums - Part 2]
  * fix typo
  * Bump requests from 2.27.1 to 2.31.0 in /docs
  * Fixed crashed in _dill._is_builtin_module when a module's
    __file__ is None
  * Bump pygments from 2.11.2 to 2.15.0 in /docs
* Thu May  4 2023 Dirk Müller <dmueller@suse.com>
- build for python 3.7+ only
* Thu Feb 16 2023 Dirk Müller <dmueller@suse.com>
- restore installation of dbm module on SLE15 and older
* Mon Nov 21 2022 Daniel Garcia <daniel.garcia@suse.com>
- Update the source from github and use the correct folder for setup and tests
* Thu Nov 17 2022 Daniel Garcia <daniel.garcia@suse.com>
- Remove python_module macro definition
- Use sources from github, current release doesn't have tests
- Use autosetup instead of setup
- Update how to run tests
- More specific python_sitelib in %%files
- Update to 0.3.6:
  * fix: #480 create_code for 3.11.0a7 and 3.11.0b1
  * fix: #413, fix: #453, drop 2.7 support
  * adjust save_code and _create_code for co_lnotab in PEP626 (#495)
  * Lookup qualname instead of name in Python 3 (#486)
  * Support PyCapsule (#477)
  * Fix `dill._dill` submodule being saved as `GLOBAL "dill._shims" "_dill"`
    (#490)
  * Create a soft_def shim to combine move_to and Getattr (#473)
  * Incidental implementation specific types (#472)
  * Fix bug in pickling MappingProxyType in PyPy 3.7+ (#506)
  * Bring back old method pickling function (#511)
  * protect against sys.modules contents change
  * correct failures and succeeds dicts
  * correct failures for registered
  * unregister SymtableEntryType
  * Add detailed trace mode showing saved object size and visual depth level
    (#471)
  * Kickstart support drop for Python < 3.7 (#499)
  * fix #521: support develop mode
  * Rewrite _create_code() with Structural Pattern Matching (limited to tuples)
    (#496)
  * fix #522: unify README and module doc
  * add some no-indent bullets
  * Fix load_session() and restrict loading a session in a different module
    (#507)
  * update load_module dump_module docs
  * fix dump_module() bugs and rename parameter 'main' to 'module' (#526)
  * A temporary quick fix for dataclass serialization (#500) (#503)
  * fix: #528, test_registered syncs objects w typemap
  * print on fail for test_registered
  * CLibraryLoader on unix in 3.11
  * add logger module to sphinx
  * Move session-related code to new session module (#530)
  * fix: #517 special handling of typing module
  * test special case typing.Any
  * more clearly note cpython bug
  * Temporary quick fix for getsource() on IPython interpreter (fixes #346)
    (#531)
  * Fix pickling errors thrown when saving some Stdlib modules (#529)
  * Fix `pickles()` flagging `__builtins__` as unpickleable due to the `all()`
    function (#538)
  * Use proper SPDX identifier for License (#539)
  * Disable logging propagation, use current stderr as output (#541)
  * move numpy special register to save
  * fix pickling of CLibraryLoaderType
  * Optimize the numpy hook (#542)
  * patch to dump_module as in #535
  * ensure tempfiles are deleted by default
* Mon Oct  3 2022 Dirk Müller <dmueller@suse.com>
- update to 0.3.5.1:
  * requires python 3.7
  * skip tests with broken stftime
  * resolve symlinks when determining if module is builtin
  * support python 3.10
  * adjust for python 3.11
  * Support recursive and empty closure cells
  * use CAN_NULL for 3.11a7 and above
  * better check for travis in tests
  * parse init file for dist meta
  * drop rtfd build to 3.8
* Sun Dec 19 2021 Ben Greiner <code@bnavigator.de>
- Update to v0.3.4
  * no release notes, works with python310
- Drop 07e24913.patch released upstream
* Fri Feb 26 2021 John Vandenberg <jayvdb@gmail.com>
- Add 07e24913.patch to fix s390x and ppc64
* Fri Feb 26 2021 John Vandenberg <jayvdb@gmail.com>
- Update to v0.3.3
  * See https://github.com/uqfoundation/dill/compare/dill-0.3.2...dill-0.3.3
- from v0.3.2
  * See https://github.com/uqfoundation/dill/compare/dill-0.3.1.1...dill-0.3.2
* Sun Dec  6 2020 Benjamin Greiner <code@bnavigator.de>
- Require dbm for all python3 flavors in Tumbleweed
  gh#openSUSE/python-rpm-macros#66
* Thu Jan 30 2020 Todd R <toddrme2178@gmail.com>
- version update to 0.3.1.1
  * Add support for pickling MappingProxyType on Python3
  * Fix GetSetDescriptorType unpickling error in test_selected.py
  * add python 3.x keywords to dump and load
  * add save_socket method for socket objects
  * add support for pickling MappingProxyType
  * cleanup of Pickler,Unpickler; move dump to Pickler.dump
  * don't use multiple inheritance in Pickler,Unpickler
  * enabled to pickle __kwdefaults__ property
  * fix pickling keyword only arguments
  * fix typo in readline error message (#327)
  * more handling of 3.8 SyntaxWarnings
  * rollback register(SocketType) due to multiprocess test_pickling failure
  * unified handling of MappingProxyType and DictProxyType
* Fri Jul 26 2019 pgajdos@suse.com
- version update to 0.3.0
  * no upstream changelog
* Sat Mar 16 2019 Jan Engelhardt <jengelh@inai.de>
- Use noun phrase in summary.
- Trim description a bit, for size.
* Fri Mar  8 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 0.2.9:
  * Various test/flake updates
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Thu May  3 2018 toddrme2178@gmail.com
- Use %%license tag
* Wed Oct 18 2017 toddrme2178@gmail.com
- Implement single-spec version
- Update to 0.2.7.1
  * No changelog
* Tue Sep 30 2014 toddrme2178@gmail.com
- Initial version
